//
//  ContentView.swift
//  UITemperature
//
//  Created by Joe Gregg on 9/21/22.
//

import SwiftUI

/* Hack to hide the keyboard on a tap gesture from
   https://designcode.io/swiftui-handbook-hide-keyboard */
extension View {
    func hideKeyboard() {
        let resign = #selector(UIResponder.resignFirstResponder)
        UIApplication.shared.sendAction(resign, to: nil, from: nil, for: nil)
    }
}

struct ContentView: View {
    @State var fahrenheitTemp : String = "68"
    @State var celsiusTemp : String = "20"
    var body: some View {
        VStack {
            TextField("",text:$fahrenheitTemp)
                .onChange(of: fahrenheitTemp) { ft in
                    if let t = Double(ft) {
                        let c = (t - 32.0)*5.0/9.0
                        celsiusTemp = String(format:"%.2f",c)
                    }
                }.keyboardType(.decimalPad).padding()
            Text("degrees Fahrenheit").font(.system(size:24)).foregroundColor(.orange)
            Text("is").font(.system(size:24)).foregroundColor(.orange)
            Text(celsiusTemp).padding()
            Text("degrees Celsius").font(.system(size:24)).foregroundColor(.orange)
        }.onTapGesture {
            hideKeyboard()
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
